"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseImportUrlData = void 0;
var _types = require("../../types");
var _zod = _interopRequireDefault(require("zod"));
var _error = require("@webiny/error");
var _utils = require("@webiny/utils");
const validateData = _zod.default.object({
  /**
   * Basic model validation.
   * We will check it more thoroughly in the next step.
   */
  model: _zod.default.object({
    modelId: _zod.default.string(),
    fields: _zod.default.array(_zod.default.object({
      id: _zod.default.string(),
      fieldId: _zod.default.string(),
      type: _zod.default.string(),
      multipleValues: _zod.default.boolean().optional(),
      settings: _zod.default.object({
        fields: _zod.default.array(_zod.default.object({}).passthrough()).optional(),
        templates: _zod.default.array(_zod.default.object({}).passthrough()).optional()
      }).passthrough().optional()
    })).min(1)
  }),
  files: _zod.default.array(_zod.default.object({
    get: _zod.default.string().url(),
    head: _zod.default.string().url(),
    key: _zod.default.string(),
    checksum: _zod.default.string(),
    type: _zod.default.enum([_types.CmsImportExportFileType.ENTRIES, _types.CmsImportExportFileType.ASSETS])
  }))
});
const parseImportUrlData = input => {
  let json;
  try {
    json = typeof input === "string" ? JSON.parse(input) : input;
  } catch (ex) {
    throw new _error.WebinyError("Invalid input data provided.", "INVALID_INPUT_DATA");
  }
  const result = validateData.safeParse(json);
  if (!result.success) {
    throw (0, _utils.createZodError)(result.error);
  }
  return {
    model: result.data.model,
    files: result.data.files
  };
};
exports.parseImportUrlData = parseImportUrlData;

//# sourceMappingURL=parseImportUrlData.js.map