"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createUploadFactory = exports.Upload = void 0;
var _libStorage = require("@webiny/aws-sdk/lib-storage");
var _stream = require("stream");
var _getContentType = require("./getContentType");
const defaultFactory = options => {
  return new _libStorage.Upload(options);
};
class Upload {
  constructor(input) {
    this.client = input.client;
    const factory = input?.factory || defaultFactory;
    const params = {
      ACL: "private",
      Body: input.stream,
      Bucket: input.bucket,
      ContentType: (0, _getContentType.getContentType)(input.filename),
      Key: input.filename
    };
    this.upload = factory({
      client: input.client,
      params,
      queueSize: input.queueSize || 1,
      partSize: 1024 * 1024 * 5,
      leavePartsOnError: false
    });
    this.stream = input.stream;
  }
  async abort() {
    await this.upload.abort();
  }
  async done() {
    try {
      return await this.upload.done();
    } catch (ex) {
      await this.abort();
      throw ex;
    }
  }
  onProgress(listener) {
    this.upload.on("httpUploadProgress", listener);
  }
}
exports.Upload = Upload;
const createUploadFactory = params => {
  return (filename, options) => {
    const stream = options?.stream || new _stream.PassThrough({
      autoDestroy: true
    });
    if (stream.listenerCount("error") === 0) {
      stream.on("error", ex => {
        console.log("Upload Stream Error", ex);
        throw ex;
      });
    }
    return new Upload({
      client: options?.client || params.client,
      bucket: options?.bucket || params.bucket,
      stream,
      filename
    });
  };
};
exports.createUploadFactory = createUploadFactory;

//# sourceMappingURL=Upload.js.map